import Flutter
import UIKit
import SCSDKLoginKit


public class SwiftSnapchatFlutterPlugin: NSObject, FlutterPlugin {
    var dataValue = [AnyHashable:Any]()
    
   public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "snapchat_flutter_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftSnapchatFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
}

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if call.method.elementsEqual("getPlatformVersion") {
        result("iOS " + UIDevice.current.systemVersion)
    }else if call.method.elementsEqual("snap_chat_login"){
        self.perform(#selector(openSnapChat), with: nil, afterDelay: 0.0)
    }else if call.method.elementsEqual("snap_chat_logout"){
        self.logout()
        result("logout")
    }else{
        result(FlutterMethodNotImplemented)
    }
  }

    @objc func openSnapChat( result: @escaping FlutterResult){
        SCSDKLoginClient.login(from: UIApplication.shared.keyWindow?.rootViewController ?? UIViewController(), completion: { success, error in
            if let error = error {
                print(error.localizedDescription)
                result(error.localizedDescription)
                return
            }
            if success {
                self.fetchSnapUserInfo(result: result)
            }
        })
    }
    private func fetchSnapUserInfo(result:@escaping FlutterResult){
        let graphQLQuery = "{me{displayName, bitmoji{avatar}, externalId}},"

        SCSDKLoginClient
            .fetchUserData(
                withQuery: graphQLQuery,
                variables: nil,
                success: { userInfo in
                    result(userInfo)
                    print(userInfo ?? "")
            }) { (error, isUserLoggedOut) in
                result(error?.localizedDescription ?? "")
                print(error?.localizedDescription ?? "")
        }
    }
    
    private func logout(){
        SCSDKLoginClient.unlinkAllSessions { (isLogout) in
            print("Logout")
        }
    }

}
